@@ -7,7 +7,7 @@ from objects.qubit import Qubit
 from objects.quantum_storage import QuantumStorage
 from objects.classical_storage import ClassicalStorage
 from objects.message import Message
-from backends.cqc_backend import CQCBackend
+from backends.eqsn_backend import EQSNBackend
 import uuid
 import time
 
@@ -35,7 +35,7 @@ class Host:
         self._classical_connections = []
         self._quantum_connections = []
         if backend is None:
-            self._backend = CQCBackend()
+            self._backend = EQSNBackend()
         else:
             self._backend = backend
         # add this host to the backend
@@ -359,6 +359,19 @@ class Host:
 
         return self._seq_number_sender[host]
 
+    def get_sequence_number_receiver(self, host):
+
+        '''
+
+        :param host:
+        :return:
+        '''
+
+        if host not in self._seq_number_receiver:
+            return 0
+
+        return self._seq_number_receiver[host][1]
+
     def _get_message_w_seq_num(self, sender_id, seq_num, wait=-1):
         """
         Get a message from a sender with a specific sequence number.
@@ -476,8 +489,7 @@ class Host:
                 expected_seq += 1
         elif seq_num > expected_seq:
             self._seq_number_sender_ack[sender][0].append(seq_num)
-        else:
-            raise Exception("Should never happen!")
+
         for t in self._ack_receiver_queue:
             res = check_task(*t)
             if res is True:
@@ -1118,7 +1130,7 @@ class Host:
         i = 0
         check_qubits = []
         while i < len(qubits):
-            check = Qubit(self.host_id)
+            check = Qubit(self)
             j = 0
             while j < size_per_qubit:
                 qubits[i + j].cnot(check)
